@@ -1,8 +1,8 @@
 #######################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Test-Perl-Critic/lib/Test/Perl/Critic.pm $
-#     $Date: 2006-03-22 22:41:46 -0800 (Wed, 22 Mar 2006) $
-#   $Author: thaljef $
-# $Revision: 346 $
+#     $Date: 2006-05-03 12:46:29 -0700 (Wed, 03 May 2006) $
+#   $Author: chrisdolan $
+# $Revision: 404 $
 ########################################################################
 
 package Test::Perl::Critic;
@@ -10,11 +10,13 @@ package Test::Perl::Critic;
 use strict;
 use warnings;
 use English qw(-no_match_vars);
+use File::Spec;
 use Test::Builder;
 use Perl::Critic;
-use File::Spec;
+use Perl::Critic::Utils;
 
-our $VERSION = '0.05';
+
+our $VERSION = '0.06';
 $VERSION = eval $VERSION;    ## no critic
 
 my $TEST        = Test::Builder->new();
@@ -65,12 +67,12 @@ sub critic_ok {
 
 
     if ($EVAL_ERROR) {           # Trap exceptions from P::C
-	$TEST->diag( "\n" );     #Just to get on a new line.
+	$TEST->diag( "\n" );     # Just to get on a new line.
         $TEST->diag( qq{Perl::Critic had errors in '$file':} );
 	$TEST->diag( qq{\t$EVAL_ERROR} );
     }
     elsif ( !$ok ) {                 # Report Policy violations
-        $TEST->diag( "\n" );         #Just to get on a new line.
+        $TEST->diag( "\n" );         # Just to get on a new line.
         $TEST->diag( qq{Perl::Critic found these violations in '$file':} );
 	$FORMAT =~ s{\%f}{$file}gmx; #HACK! Violation doesn't know the file
 
@@ -87,7 +89,8 @@ sub critic_ok {
 
 sub all_critic_ok {
 
-    my @files = all_code_files(@_);
+    my @dirs = @_ ? @_ : _starting_points();
+    my @files = all_code_files( @dirs );
     $TEST->plan( tests => scalar @files );
 
     my $ok = 1;
@@ -100,27 +103,8 @@ sub all_critic_ok {
 #---------------------------------------------------------------------------
 
 sub all_code_files {
-
-    my @queue      = @_ ? @_ : _starting_points();
-    my @code_files = ();
-
-    while (@queue) {
-        my $file = shift @queue;
-        if ( -d $file ) {
-            opendir my ($dh), $file or next;
-            my @newfiles = sort readdir $dh;
-            closedir $dh;
-
-            @newfiles = File::Spec->no_upwards(@newfiles);
-            @newfiles = grep { $_ ne 'CVS' && $_ ne '.svn' }    @newfiles;
-            push @queue, map { File::Spec->catfile($file, $_) } @newfiles;
-        }
-
-        if ( -f $file && _is_perl($file) ) {
-            push @code_files, $file;
-        }
-    }
-    return @code_files;
+    my @dirs = @_ ? @_ : _starting_points();
+    return Perl::Critic::Utils::all_perl_files(@dirs);
 }
 
 #---------------------------------------------------------------------------
@@ -130,26 +114,9 @@ sub _starting_points {
 }
 
 #---------------------------------------------------------------------------
-sub _is_perl {
-    my $file = shift;
-
-    #Check filename extensions
-    return 1 if $file =~ m{ [.] PL          \z}mx;
-    return 1 if $file =~ m{ [.] p (?: l|m ) \z}mx;
-    return 1 if $file =~ m{ [.] t           \z}mx;
-
-    #Check for shebang
-    open my ($fh), '<', $file or return;
-    my $first = <$fh>;
-    close $fh;
-
-    return 1 if defined $first && ( $first =~ m{ \A \#!.*perl }mx );
-    return;
-}
 
 1;
 
-#---------------------------------------------------------------------------
 
 __END__
 
@@ -207,6 +174,9 @@ generate this and several other standard test scripts for you.
 
 =item all_code_files ( [@DIRECTORIES] )
 
+B<DEPRECATED:> Use the C<all_perl_files> subroutine that is exported
+by L<Perl::Critic::Utils> instead.
+
 Returns a list of all the Perl files found beneath each DIRECTORY, If
 @DIRECTORIES is an empty list, defaults to F<blib/>.  If F<blib/> does
 not exist, it tries F<lib/>.  Skips any files in CVS or Subversion
@@ -272,6 +242,10 @@ are:
   %p        Name of the Policy module that created the violation
   %s        The severity level of the violation
 
+The default format is:
+
+  "\t%m at line %l, column %c. %e"
+
 =head1 CAVEATS
 
 Despite the obvious convenience of using test scripts to verify that
